@@ -10,15 +10,11 @@
 #   by Leslie Michael Orchard <deus_x@nijacode.com>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-#   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
+#   Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: Filters.pm,v 2.86 2006/05/30 17:01:28 abw Exp $
-#
 #============================================================================
 
 package Template::Filters;
@@ -28,8 +24,10 @@ use warnings;
 use locale;
 use base 'Template::Base';
 use Template::Constants;
+use Scalar::Util 'blessed';
 
-our $VERSION = 2.85;
+our $VERSION   = 2.86;
+our $AVAILABLE = { };
 
 
 #------------------------------------------------------------------------
@@ -49,7 +47,9 @@ our $FILTERS = {
     'html_break'      => \&html_para_break,
     'html_para_break' => \&html_para_break,
     'html_line_break' => \&html_line_break,
+    'xml'             => \&xml_filter,
     'uri'             => \&uri_filter,
+    'url'             => \&url_filter,
     'upper'           => sub { uc $_[0] },
     'lower'           => sub { lc $_[0] },
     'ucfirst'         => sub { ucfirst $_[0] },
@@ -115,7 +115,7 @@ sub fetch {
     # non-refs are assumed to be regular name lookups
 
     if (ref $name) {
-        if (UNIVERSAL::isa($name, $PLUGIN_FILTER)) {
+        if (blessed($name) && $name->isa($PLUGIN_FILTER)) {
             $factory = $name->factory()
                 || return $self->error($name->error());
         }
@@ -261,7 +261,7 @@ sub _dump {
 #
 # URI escape a string.  This code is borrowed from Gisle Aas' URI::Escape
 # module, copyright 1995-2004.  See RFC2396 for details.
-#------------------------------------------------------------------------
+#-----------------------------------------------------------------------
 
 # cache of escaped characters
 our $URI_ESCAPES;
@@ -273,7 +273,7 @@ sub uri_filter {
         map { ( chr($_), sprintf("%%%02X", $_) ) } (0..255),
     };
 
-    if ($] >= 5.008) {
+    if ($] >= 5.008 && utf8::is_utf8($text)) {
         utf8::encode($text);
     }
     
@@ -281,6 +281,31 @@ sub uri_filter {
     $text;
 }
 
+#------------------------------------------------------------------------
+# url_filter()                                           [% FILTER uri %]
+#
+# NOTE: the difference: url vs uri. 
+# This implements the old-style, non-strict behaviour of the uri filter 
+# which allows any valid URL characters to pass through so that 
+# http://example.com/blah.html does not get the ':' and '/' characters 
+# munged. 
+#-----------------------------------------------------------------------
+
+sub url_filter {
+    my $text = shift;
+
+    $URI_ESCAPES ||= {
+        map { ( chr($_), sprintf("%%%02X", $_) ) } (0..255),
+    };
+
+    if ($] >= 5.008 && utf8::is_utf8($text)) {
+        utf8::encode($text);
+    }
+    
+    $text =~ s/([^;\/?:@&=+\$,A-Za-z0-9\-_.!~*'()])/$URI_ESCAPES->{$1}/eg;
+    $text;
+}
+
 
 #------------------------------------------------------------------------
 # html_filter()                                         [% FILTER html %]
@@ -301,6 +326,26 @@ sub html_filter {
 }
 
 
+#------------------------------------------------------------------------
+# xml_filter()                                           [% FILTER xml %]
+#
+# Same as the html filter, but adds the conversion of ' to &apos; which
+# is native to XML.
+#------------------------------------------------------------------------
+
+sub xml_filter {
+    my $text = shift;
+    for ($text) {
+        s/&/&amp;/g;
+        s/</&lt;/g;
+        s/>/&gt;/g;
+        s/"/&quot;/g;
+        s/'/&apos;/g;
+    }
+    return $text;
+}
+
+
 #------------------------------------------------------------------------
 # html_paragraph()                                 [% FILTER html_para %]
 #
@@ -354,27 +399,32 @@ sub html_line_break  {
 # modules can't be located.
 #------------------------------------------------------------------------
 
+sub use_html_entities {
+    require HTML::Entities;
+    return ($AVAILABLE->{ HTML_ENTITY } = \&HTML::Entities::encode_entities);
+}
+
+sub use_apache_util {
+    require Apache::Util;
+    Apache::Util::escape_html('');      # TODO: explain this
+    return ($AVAILABLE->{ HTML_ENTITY } = \&Apache::Util::escape_html);
+}
+
 sub html_entity_filter_factory {
     my $context = shift;
+    my $haz;
+    
+    # if Apache::Util is installed then we use escape_html
+    $haz = $AVAILABLE->{ HTML_ENTITY } 
+       ||  eval { use_apache_util()   }
+       ||  eval { use_html_entities() }
+       ||  -1;      # we use -1 for "not available" because it's a true value
 
-    # if Apache::Util is installed then we use it
-    eval { 
-        require Apache::Util;
-        Apache::Util::escape_html('');
-    };
-    return \&Apache::Util::escape_html
-        unless $@;
-
-    # otherwise if HTML::Entities is installed then we use that
-    eval {
-        require HTML::Entities;
-    };
-    return \&HTML::Entities::encode_entities
-        unless $@;
-
-    return (undef, Template::Exception->new( html_entity => 
-                    'cannot locate Apache::Util or HTML::Entities' ));
-
+    return ref $haz eq 'CODE'
+        ? $haz
+        : (undef, Template::Exception->new( 
+            html_entity => 'cannot locate Apache::Util or HTML::Entities' )
+          );
 }
 
 
@@ -492,7 +542,6 @@ sub truncate_filter_factory {
 }
 
 
-
 #------------------------------------------------------------------------
 # eval_filter_factory                                   [% FILTER eval %]
 # 
@@ -594,18 +643,6 @@ sub stdout_filter_factory {
 
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template::Filters - Post-processing filters for template blocks
@@ -613,35 +650,42 @@ Template::Filters - Post-processing filters for template blocks
 =head1 SYNOPSIS
 
     use Template::Filters;
-
+    
     $filters = Template::Filters->new(\%config);
-
+    
     ($filter, $error) = $filters->fetch($name, \@args, $context);
+    
+    if ($filter) {
+        print &$filter("some text");
+    }
+    else {
+        print "Could not fetch $name filter: $error\n";
+    }
 
 =head1 DESCRIPTION
 
-The Template::Filters module implements a provider for creating and/or
-returning subroutines that implement the standard filters.  Additional 
-custom filters may be provided via the FILTERS options.
+The C<Template::Filters> module implements a provider for creating subroutines
+that implement the standard filters. Additional custom filters may be provided
+via the L<FILTERS> configuration option.
 
 =head1 METHODS
 
 =head2 new(\%params) 
 
 Constructor method which instantiates and returns a reference to a
-Template::Filters object.  A reference to a hash array of configuration
+C<Template::Filters> object.  A reference to a hash array of configuration
 items may be passed as a parameter.  These are described below.  
 
     my $filters = Template::Filters->new({
         FILTERS => { ... },
     });
-
+    
     my $template = Template->new({
         LOAD_FILTERS => [ $filters ],
     });
 
-A default Template::Filters module is created by the Template.pm module
-if the LOAD_FILTERS option isn't specified.  All configuration parameters
+A default C<Template::Filters> module is created by the L<Template> module
+if the L<LOAD_FILTERS> option isn't specified.  All configuration parameters
 are forwarded to the constructor.
 
     $template = Template->new({
@@ -652,596 +696,98 @@ are forwarded to the constructor.
 
 Called to request that a filter of a given name be provided.  The name
 of the filter should be specified as the first parameter.  This should
-be one of the standard filters or one specified in the FILTERS
+be one of the standard filters or one specified in the L<FILTERS>
 configuration hash.  The second argument should be a reference to an
 array containing configuration parameters for the filter.  This may be
 specified as 0, or undef where no parameters are provided.  The third
-argument should be a reference to the current Template::Context
+argument should be a reference to the current L<Template::Context>
 object.
 
 The method returns a reference to a filter sub-routine on success.  It
-may also return (undef, STATUS_DECLINE) to decline the request, to allow
-delegation onto other filter providers in the LOAD_FILTERS chain of 
-responsibility.  On error, ($error, STATUS_ERROR) is returned where $error
-is an error message or Template::Exception object indicating the error
+may also return C<(undef, STATUS_DECLINE)> to decline the request, to allow
+delegation onto other filter providers in the L<LOAD_FILTERS> chain of 
+responsibility.  On error, C<($error, STATUS_ERROR)> is returned where $error
+is an error message or L<Template::Exception> object indicating the error
 that occurred. 
 
-When the TOLERANT option is set, errors are automatically downgraded to
-a STATUS_DECLINE response.
+When the C<TOLERANT> option is set, errors are automatically downgraded to
+a C<STATUS_DECLINE> response.
 
+=head2 use_html_entities()
+
+This class method can be called to configure the C<html_entity> filter to use
+the L<HTML::Entities> module. An error will be raised if it is not installed
+on your system.
+
+    use Template::Filters;
+    Template::Filters->use_html_entities();
+
+=head2 use_apache_util()
+
+This class method can be called to configure the C<html_entity> filter to use
+the L<Apache::Util> module. An error will be raised if it is not installed on
+your system.
+
+    use Template::Filters;
+    Template::Filters->use_apache_util();
 
 =head1 CONFIGURATION OPTIONS
 
-The following list details the configuration options that can be provided
-to the Template::Filters new() constructor.
+The following list summarises the configuration options that can be provided
+to the C<Template::Filters> L<new()> constructor. Please see
+L<Template::Manual::Config> for further information about each option.
 
-=over 4
+=head2 FILTERS
 
-
-
-
-=item FILTERS
-
-The FILTERS option can be used to specify custom filters which can
-then be used with the FILTER directive like any other.  These are
-added to the standard filters which are available by default.  Filters
-specified via this option will mask any standard filters of the same
-name.
-
-The FILTERS option should be specified as a reference to a hash array
-in which each key represents the name of a filter.  The corresponding
-value should contain a reference to an array containing a subroutine
-reference and a flag which indicates if the filter is static (0) or
-dynamic (1).  A filter may also be specified as a solitary subroutine
-reference and is assumed to be static.
+The L<FILTERS|Template::Manual::Config#FILTERS> option can be used to specify
+custom filters which can then be used with the
+L<FILTER|Template::Manual::Directives#FILTER> directive like any other. These
+are added to the standard filters which are available by default.
 
     $filters = Template::Filters->new({
         FILTERS => {
-            'sfilt1' =>   \&static_filter,      # static
-            'sfilt2' => [ \&static_filter, 0 ], # same as above
+            'sfilt1' =>   \&static_filter,
             'dfilt1' => [ \&dyanamic_filter_factory, 1 ],
         },
     });
 
-Additional filters can be specified at any time by calling the 
-define_filter() method on the current Template::Context object.
-The method accepts a filter name, a reference to a filter 
-subroutine and an optional flag to indicate if the filter is 
-dynamic.
+=head2 TOLERANT
 
-    my $context = $template->context();
-    $context->define_filter('new_html', \&new_html);
-    $context->define_filter('new_repeat', \&new_repeat, 1);
+The L<TOLERANT|Template::Manual::Config#TOLERANT> flag can be set to indicate
+that the C<Template::Filters> module should ignore any errors and instead
+return C<STATUS_DECLINED>.
 
-Static filters are those where a single subroutine reference is used
-for all invocations of a particular filter.  Filters that don't accept
-any configuration parameters (e.g. 'html') can be implemented
-statically.  The subroutine reference is simply returned when that
-particular filter is requested.  The subroutine is called to filter
-the output of a template block which is passed as the only argument.
-The subroutine should return the modified text.
+=head2 DEBUG
 
-    sub static_filter {
-        my $text = shift;
-        # do something to modify $text...
-        return $text;
-    }
-
-The following template fragment:
-
-    [% FILTER sfilt1 %]
-    Blah blah blah.
-    [% END %]
-
-is approximately equivalent to:
-
-    &static_filter("\nBlah blah blah.\n");
-
-Filters that can accept parameters (e.g. 'truncate') should be
-implemented dynamically.  In this case, the subroutine is taken to be
-a filter 'factory' that is called to create a unique filter subroutine
-each time one is requested.  A reference to the current
-Template::Context object is passed as the first parameter, followed by
-any additional parameters specified.  The subroutine should return
-another subroutine reference (usually a closure) which implements the
-filter.
-
-    sub dynamic_filter_factory {
-        my ($context, @args) = @_;
-
-        return sub {
-            my $text = shift;
-            # do something to modify $text...
-            return $text;           
-        }
-    }
-
-The following template fragment:
-
-    [% FILTER dfilt1(123, 456) %] 
-    Blah blah blah
-    [% END %]              
-
-is approximately equivalent to:
-
-    my $filter = &dynamic_filter_factory($context, 123, 456);
-    &$filter("\nBlah blah blah.\n");
-
-See the FILTER directive for further examples.
-
-
-
-
-=item TOLERANT
-
-The TOLERANT flag is used by the various Template Toolkit provider
-modules (Template::Provider, Template::Plugins, Template::Filters) to
-control their behaviour when errors are encountered.  By default, any
-errors are reported as such, with the request for the particular
-resource (template, plugin, filter) being denied and an exception
-raised.  When the TOLERANT flag is set to any true values, errors will
-be silently ignored and the provider will instead return
-STATUS_DECLINED.  This allows a subsequent provider to take
-responsibility for providing the resource, rather than failing the
-request outright.  If all providers decline to service the request,
-either through tolerated failure or a genuine disinclination to
-comply, then a 'E<lt>resourceE<gt> not found' exception is raised.
-
-
-
-
-=item DEBUG
-
-The DEBUG option can be used to enable debugging messages from the
-Template::Filters module by setting it to include the DEBUG_FILTERS
-value.
+The L<DEBUG|Template::Manual::Config#DEBUG> option can be used to enable
+debugging messages for the Template::Filters module by setting it to include
+the C<DEBUG_FILTERS> value.
 
     use Template::Constants qw( :debug );
-
+    
     my $template = Template->new({
-	DEBUG => DEBUG_FILTERS | DEBUG_PLUGINS,
+        DEBUG => DEBUG_FILTERS | DEBUG_PLUGINS,
     });
 
+=head1 STANDARD FILTERS
 
-
-
-=back
-
-=head1 TEMPLATE TOOLKIT FILTERS
-
-The following standard filters are distributed with the Template Toolkit.
-
-
-
-=head2 format(format)
-
-The 'format' filter takes a format string as a parameter (as per
-printf()) and formats each line of text accordingly.
-
-    [% FILTER format('<!-- %-40s -->') %]
-    This is a block of text filtered 
-    through the above format.
-    [% END %]
-
-output:
-
-    <!-- This is a block of text filtered        -->
-    <!-- through the above format.               -->
-
-=head2 upper
-
-Folds the input to UPPER CASE.
-
-    [% "hello world" FILTER upper %]
-
-output:
-
-    HELLO WORLD
-
-=head2 lower
-
-Folds the input to lower case.
-
-    [% "Hello World" FILTER lower %]
-
-output:
-
-    hello world
-
-=head2 ucfirst
-
-Folds the first character of the input to UPPER CASE.
-
-    [% "hello" FILTER ucfirst %]
-
-output:
-
-    Hello
-
-=head2 lcfirst
-
-Folds the first character of the input to lower case.
-
-    [% "HELLO" FILTER lcfirst %]
-
-output:
-
-    hELLO
-
-=head2 trim
-
-Trims any leading or trailing whitespace from the input text.  Particularly 
-useful in conjunction with INCLUDE, PROCESS, etc., having the same effect
-as the TRIM configuration option.
-
-    [% INCLUDE myfile | trim %]
-
-=head2 collapse
-
-Collapse any whitespace sequences in the input text into a single space.
-Leading and trailing whitespace (which would be reduced to a single space)
-is removed, as per trim.
-
-    [% FILTER collapse %]
-
-       The   cat
-
-       sat    on
-
-       the   mat
-
-    [% END %]
-
-output:
-
-    The cat sat on the mat
-
-=head2 html
-
-Converts the characters 'E<lt>', 'E<gt>', '&' and '"' to '&lt;',
-'&gt;', '&amp;', and '&quot;' respectively, protecting them from being
-interpreted as representing HTML tags or entities.
-
-    [% FILTER html %]
-    Binary "<=>" returns -1, 0, or 1 depending on...
-    [% END %]
-
-output:
-
-    Binary "&lt;=&gt;" returns -1, 0, or 1 depending on...
-
-=head2 html_entity
-
-The html filter is fast and simple but it doesn't encode the full
-range of HTML entities that your text may contain.  The html_entity
-filter uses either the Apache::Util module (which is written in C and
-is therefore faster) or the HTML::Entities module (written in Perl but
-equally as comprehensive) to perform the encoding.  If one or other of
-these modules are installed on your system then the text will be
-encoded (via the escape_html() or encode_entities() subroutines
-respectively) to convert all extended characters into their
-appropriate HTML entities (e.g. converting '' to '&eacute;').  If
-neither module is available on your system then an 'html_entity' exception
-will be thrown reporting an appropriate message.   
-
-For further information on HTML entity encoding, see
-http://www.w3.org/TR/REC-html40/sgml/entities.html.
-
-=head2 html_para
-
-This filter formats a block of text into HTML paragraphs.  A sequence of 
-two or more newlines is used as the delimiter for paragraphs which are 
-then wrapped in HTML E<lt>pE<gt>...E<lt>/pE<gt> tags.
-
-    [% FILTER html_para %]
-    The cat sat on the mat.
-
-    Mary had a little lamb.
-    [% END %]
-
-output:
-
-    <p>
-    The cat sat on the mat.
-    </p>
-
-    <p>
-    Mary had a little lamb.
-    </p>
-
-=head2 html_break / html_para_break
-
-Similar to the html_para filter described above, but uses the HTML tag
-sequence E<lt>brE<gt>E<lt>brE<gt> to join paragraphs.
-
-    [% FILTER html_break %]
-    The cat sat on the mat.
-
-    Mary had a little lamb.
-    [% END %]
-
-output:
-
-    The cat sat on the mat.
-    <br>
-    <br>
-    Mary had a little lamb.
-
-=head2 html_line_break
-
-This filter replaces any newlines with E<lt>brE<gt> HTML tags,
-thus preserving the line breaks of the original text in the 
-HTML output.
-
-    [% FILTER html_line_break %]
-    The cat sat on the mat.
-    Mary had a little lamb.
-    [% END %]
-
-output:
-
-    The cat sat on the mat.<br>
-    Mary had a little lamb.<br>
-
-=head2 uri
-
-This filter URI escapes the input text, converting any characters 
-outside of the permitted URI character set (as defined by RFC 2396)
-into a C<%nn> hex escape.
-
-    [% 'my file.html' | uri %]
-
-output:
-
-    my%20file.html
-
-Note that as of TT version 2.16, the uri filter now correctly encodes
-all reserved characters.  This includes C<&>, C<@>, C</>, C<;>, C<:>,
-C<=>, C<+>, C<?> and C<$> which were not escaped (incorrectly) by the
-uri filter in versions 2.15 and earlier.  See RFC 2396 for further
-details.
-
-=head2 indent(pad)
-
-Indents the text block by a fixed pad string or width.  The 'pad' argument
-can be specified as a string, or as a numerical value to indicate a pad
-width (spaces).  Defaults to 4 spaces if unspecified.
-
-    [% FILTER indent('ME> ') %]
-    blah blah blah
-    cabbages, rhubard, onions
-    [% END %]
-
-output:
-
-    ME> blah blah blah
-    ME> cabbages, rhubard, onions
-
-=head2 truncate(length,dots)
-
-Truncates the text block to the length specified, or a default length
-of 32.  Truncated text will be terminated with '...' (i.e. the '...'
-falls inside the required length, rather than appending to it).
-
-    [% FILTER truncate(21) %]
-    I have much to say on this matter that has previously 
-    been said on more than one occasion.
-    [% END %]
-
-output:
-
-    I have much to say...
-
-If you want to use something other than '...' you can pass that as a 
-second argument.
-
-    [% FILTER truncate(26, '&hellip;') %]
-    I have much to say on this matter that has previously 
-    been said on more than one occasion.
-    [% END %]
-
-output:
-
-    I have much to say&hellip;
-
-=head2 repeat(iterations)
-
-Repeats the text block for as many iterations as are specified (default: 1).
-
-    [% FILTER repeat(3) %]
-    We want more beer and we want more beer,
-    [% END %]
-    We are the more beer wanters!
-
-output:
-
-    We want more beer and we want more beer,
-    We want more beer and we want more beer,
-    We want more beer and we want more beer,
-    We are the more beer wanters!
-
-=head2 remove(string) 
-
-Searches the input text for any occurrences of the specified string and 
-removes them.  A Perl regular expression may be specified as the search 
-string.
-
-    [% "The  cat  sat  on  the  mat" FILTER remove('\s+') %]
-
-output: 
-
-    Thecatsatonthemat
-
-=head2 replace(search, replace) 
-
-Similar to the remove filter described above, but taking a second parameter
-which is used as a replacement string for instances of the search string.
-
-    [% "The  cat  sat  on  the  mat" | replace('\s+', '_') %]
-
-output: 
-
-    The_cat_sat_on_the_mat
-
-=head2 redirect(file, options)
-
-The 'redirect' filter redirects the output of the block into a separate
-file, specified relative to the OUTPUT_PATH configuration item.
-
-    [% FOREACH user = myorg.userlist %]
-       [% FILTER redirect("users/${user.id}.html") %]
-          [% INCLUDE userinfo %]
-       [% END %]
-    [% END %]
-
-or more succinctly, using side-effect notation:
-
-    [% INCLUDE userinfo 
-         FILTER redirect("users/${user.id}.html")
-	   FOREACH user = myorg.userlist 
-    %]
-
-A 'file' exception will be thrown if the OUTPUT_PATH option is undefined.
-
-An optional 'binmode' argument can follow the filename to explicitly set
-the output file to binary mode.
-
-    [% PROCESS my/png/generator 
-         FILTER redirect("images/logo.png", binmode=1) %]
-
-For backwards compatibility with earlier versions, a single true/false
-value can be used to set binary mode.
-
-    [% PROCESS my/png/generator 
-         FILTER redirect("images/logo.png", 1) %]
-
-For the sake of future compatibility and clarity, if nothing else, we
-would strongly recommend you explicitly use the named 'binmode' option
-as shown in the first example.
-
-=head2 eval / evaltt
-
-The 'eval' filter evaluates the block as template text, processing
-any directives embedded within it.  This allows template variables to
-contain template fragments, or for some method to be provided for
-returning template fragments from an external source such as a
-database, which can then be processed in the template as required.
-
-    my $vars  = {
-	fragment => "The cat sat on the [% place %]",
-    };
-    $template->process($file, $vars);
-
-The following example:
-
-    [% fragment | eval %]
-
-is therefore equivalent to 
-
-    The cat sat on the [% place %]
-
-The 'evaltt' filter is provided as an alias for 'eval'.
-
-=head2 perl / evalperl
-
-The 'perl' filter evaluates the block as Perl code.  The EVAL_PERL
-option must be set to a true value or a 'perl' exception will be
-thrown.
-
-    [% my_perl_code | perl %]
-
-In most cases, the [% PERL %] ... [% END %] block should suffice for 
-evaluating Perl code, given that template directives are processed 
-before being evaluate as Perl.  Thus, the previous example could have
-been written in the more verbose form:
-
-    [% PERL %]
-    [% my_perl_code %]
-    [% END %]
-
-as well as
-
-    [% FILTER perl %]
-    [% my_perl_code %]
-    [% END %]
-
-The 'evalperl' filter is provided as an alias for 'perl' for backwards
-compatibility.
-
-=head2 stdout(options)
-
-The stdout filter prints the output generated by the enclosing block to
-STDOUT.  The 'binmode' option can be passed as either a named parameter
-or a single argument to set STDOUT to binary mode (see the
-binmode perl function).
-
-    [% PROCESS something/cool
-           FILTER stdout(binmode=1) # recommended %]
-
-    [% PROCESS something/cool
-           FILTER stdout(1)         # alternate %]
-
-The stdout filter can be used to force binmode on STDOUT, or also inside
-redirect, null or stderr blocks to make sure that particular output goes
-to stdout. See the null filter below for an example.
-
-=head2 stderr
-
-The stderr filter prints the output generated by the enclosing block to
-STDERR.
-
-=head2 null
-
-The null filter prints nothing.  This is useful for plugins whose
-methods return values that you don't want to appear in the output.
-Rather than assigning every plugin method call to a dummy variable
-to silence it, you can wrap the block in a null filter:
-
-    [% FILTER null;
-        USE im = GD.Image(100,100);
-        black = im.colorAllocate(0,   0, 0);
-        red   = im.colorAllocate(255,0,  0);
-        blue  = im.colorAllocate(0,  0,  255);
-        im.arc(50,50,95,75,0,360,blue);
-        im.fill(50,50,red);
-        im.png | stdout(1);
-       END;
-    -%]
-
-Notice the use of the stdout filter to ensure that a particular expression
-generates output to stdout (in this case in binary mode).
-
-=head2 latex(outputType)
-
-The latex() filter is no longer part of the core Template Toolkit
-distribution as of version 2.15.  You can download it as a 
-separate Template-Latex distribution from CPAN.
+Please see L<Template::Manual::Filters> for a list of the filters provided
+with the Template Toolkit, complete with examples of use.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
-
-L<http://wardley.org/|http://wardley.org/>
-
-
-
-
-=head1 VERSION
-
-2.85, distributed as part of the
-Template Toolkit version 2.18, released on 09 February 2007.
+Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
-
+Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template|Template>, L<Template::Context|Template::Context>, L<Template::Manual::Filters|Template::Manual::Filters>
+L<Template::Manual::Filters>, L<Template>, L<Template::Context>
 
 =cut
 
