@@ -11,14 +11,11 @@
 #   Andy Wardley           <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 2000-2006 Thierry-Michel Barral, Andy Wardley.
+#   Copyright (C) 2000-2007 Thierry-Michel Barral, Andy Wardley.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: Date.pm,v 2.77 2006/05/30 17:01:34 abw Exp $
-#
 #============================================================================
 
 package Template::Plugin::Date;
@@ -41,7 +38,7 @@ our @LOCALE_SUFFIX = qw( .ISO8859-1 .ISO_8859-15 .US-ASCII .UTF-8 );
 sub new {
     my ($class, $context, $params) = @_;
     bless {
-	$params ? %$params : ()
+        $params ? %$params : ()
     }, $class;
 }
 
@@ -78,11 +75,11 @@ sub format {
     my $self   = shift;
     my $params = ref($_[$#_]) eq 'HASH' ? pop(@_) : { };
     my $time   = shift(@_) || $params->{ time } || $self->{ time } 
-			   || $self->now();
+                           || $self->now();
     my $format = @_ ? shift(@_) 
-		    : ($params->{ format } || $self->{ format } || $FORMAT);
+                    : ($params->{ format } || $self->{ format } || $FORMAT);
     my $locale = @_ ? shift(@_)
-		    : ($params->{ locale } || $self->{ locale });
+                    : ($params->{ locale } || $self->{ locale });
     my $gmt = @_ ? shift(@_)
             : ($params->{ gmt } || $self->{ gmt });
     my (@date, $datestr);
@@ -98,25 +95,41 @@ sub format {
     }
     else {
         # if $time is numeric, then we assume it's seconds since the epoch
-        # otherwise, we try to parse it as a 'H:M:S D:M:Y' string
-        @date = (split(/(?:\/| |:|-)/, $time))[2,1,0,3..5];
-        return (undef, Template::Exception->new('date',
-               "bad time/date string:  expects 'h:m:s d:m:y'  got: '$time'"))
-            unless @date >= 6 && defined $date[5];
+        # otherwise, we try to parse it as either a 'Y:M:D H:M:S' or a
+        # 'H:M:S D:M:Y' string
+
+        my @parts = (split(/(?:\/| |:|-)/, $time));
+
+        if (@parts >= 6) {
+            if (length($parts[0]) == 4) {
+                # year is first; assume 'Y:M:D H:M:S'
+                @date = @parts[reverse 0..5];
+            }
+            else {
+                # year is last; assume 'H:M:S D:M:Y'
+                @date = @parts[2,1,0,3..5];
+            }
+        }
+
+        if (!@date) {
+            return (undef, Template::Exception->new('date',
+                   "bad time/date string:  " .
+                   "expects 'h:m:s d:m:y'  got: '$time'"));
+        }
         $date[4] -= 1;     # correct month number 1-12 to range 0-11
         $date[5] -= 1900;  # convert absolute year to years since 1900
         $time = &POSIX::mktime(@date);
     }
     
     if ($locale) {
-	# format the date in a specific locale, saving and subsequently
+        # format the date in a specific locale, saving and subsequently
         # restoring the current locale.
         my $old_locale = &POSIX::setlocale(&POSIX::LC_ALL);
 
         # some systems expect locales to have a particular suffix
         for my $suffix ('', @LOCALE_SUFFIX) {
             my $try_locale = $locale.$suffix;
-	    my $setlocale = &POSIX::setlocale(&POSIX::LC_ALL, $try_locale);
+            my $setlocale = &POSIX::setlocale(&POSIX::LC_ALL, $try_locale);
             if (defined $setlocale && $try_locale eq $setlocale) {
                 $locale = $try_locale;
                 last;
@@ -167,7 +180,7 @@ sub AUTOLOAD {
 
     my $sub = \&{"Date::Calc::$method"};
     $self->throw("no such Date::Calc method: $method")
-	unless $sub;
+        unless $sub;
 
     &$sub(@_);
 }
@@ -196,18 +209,6 @@ sub AUTOLOAD {
 
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template::Plugin::Date - Plugin to generate formatted date strings
@@ -215,70 +216,73 @@ Template::Plugin::Date - Plugin to generate formatted date strings
 =head1 SYNOPSIS
 
     [% USE date %]
-
+    
     # use current time and default format
     [% date.format %]
-
-    # specify time as seconds since epoch or 'h:m:s d-m-y' string
+    
+    # specify time as seconds since epoch
+    # or as a 'h:m:s d-m-y' or 'y-m-d h:m:s' string
     [% date.format(960973980) %]
     [% date.format('4:20:36 21/12/2000') %]
-
+    [% date.format('2000/12/21 4:20:36') %]
+    
     # specify format
     [% date.format(mytime, '%H:%M:%S') %]
-
+    
     # specify locale
     [% date.format(date.now, '%a %d %b %y', 'en_GB') %]
-
+    
     # named parameters 
     [% date.format(mytime, format = '%H:%M:%S') %]
     [% date.format(locale = 'en_GB') %]
     [% date.format(time   = date.now, 
-		   format = '%H:%M:%S', 
+                   format = '%H:%M:%S', 
                    locale = 'en_GB) %]
-   
+    
     # specify default format to plugin
     [% USE date(format = '%H:%M:%S', locale = 'de_DE') %]
-
+    
     [% date.format %]
     ...
 
 =head1 DESCRIPTION
 
-The Date plugin provides an easy way to generate formatted time and date
-strings by delegating to the POSIX strftime() routine.  
+The C<Date> plugin provides an easy way to generate formatted time and date
+strings by delegating to the C<POSIX> C<strftime()> routine.
 
 The plugin can be loaded via the familiar USE directive.
 
     [% USE date %]
 
-This creates a plugin object with the default name of 'date'.  An alternate
+This creates a plugin object with the default name of 'C<date>'.  An alternate
 name can be specified as such:
 
     [% USE myname = date %]
 
-The plugin provides the format() method which accepts a time value, a
+The plugin provides the C<format()> method which accepts a time value, a
 format string and a locale name.  All of these parameters are optional
-with the current system time, default format ('%H:%M:%S %d-%b-%Y') and
+with the current system time, default format ('C<%H:%M:%S %d-%b-%Y>') and
 current locale being used respectively, if undefined.  Default values
 for the time, format and/or locale may be specified as named parameters 
-in the USE directive.
+in the C<USE> directive.
 
     [% USE date(format = '%a %d-%b-%Y', locale = 'fr_FR') %]
 
-When called without any parameters, the format() method returns a string
-representing the current system time, formatted by strftime() according 
+When called without any parameters, the C<format()> method returns a string
+representing the current system time, formatted by C<strftime()> according 
 to the default format and for the default locale (which may not be the
-current one, if locale is set in the USE directive).
+current one, if locale is set in the C<USE> directive).
 
     [% date.format %]
 
 The plugin allows a time/date to be specified as seconds since the epoch,
-as is returned by time().
+as is returned by C<time()>.
 
     File last modified: [% date.format(filemod_time) %]
 
-The time/date can also be specified as a string of the form 'h:m:s d/m/y'.
-Any of the characters : / - or space may be used to delimit fields.
+The time/date can also be specified as a string of the form C<h:m:s d/m/y>
+or C<y/m/d h:m:s>.  Any of the characters : / - or space may be used to
+delimit fields.
 
     [% USE day = date(format => '%A', locale => 'en_GB') %]
     [% day.format('4:20:00 9-13-2000') %]  
@@ -287,7 +291,7 @@ Output:
 
     Tuesday
 
-A format string can also be passed to the format() method, and a locale
+A format string can also be passed to the C<format()> method, and a locale
 specification may follow that.
 
     [% date.format(filemod, '%d-%b-%Y') %]
@@ -299,11 +303,11 @@ seconds-since-the-epoch input:
     [% date.format(filemod, '%d-%b-%Y', 'en_GB', 1) %]
 
 Note that in this case, if the local time is not GMT, then also specifying
-'%Z' (time zone) in the format parameter will lead to an extremely 
+'C<%Z>' (time zone) in the format parameter will lead to an extremely 
 misleading result.
 
 Any or all of these parameters may be named.  Positional parameters
-should always be in the order ($time, $format, $locale).
+should always be in the order C<($time, $format, $locale)>.
 
     [% date.format(format => '%H:%M:%S') %]
     [% date.format(time => filemod, format => '%H:%M:%S') %]
@@ -312,18 +316,18 @@ should always be in the order ($time, $format, $locale).
     [% date.format(mytime, format => '%H:%M:%S', gmt => 1) %]
     ...etc...
 
-The now() method returns the current system time in seconds since the 
+The C<now()> method returns the current system time in seconds since the 
 epoch.  
 
     [% date.format(date.now, '%A') %]
 
-The calc() method can be used to create an interface to the Date::Calc
+The C<calc()> method can be used to create an interface to the C<Date::Calc>
 module (if installed on your system).
 
     [% calc = date.calc %]
     [% calc.Monday_of_Week(22, 2001).join('/') %]
 
-The manip() method can be used to create an interface to the Date::Manip
+The C<manip()> method can be used to create an interface to the C<Date::Manip>
 module (if installed on your system).
 
     [% manip = date.manip %]
@@ -331,30 +335,21 @@ module (if installed on your system).
 
 =head1 AUTHORS
 
-Thierry-Michel Barral E<lt>kktos@electron-libre.comE<gt> wrote the original
-plugin.
+Thierry-Michel Barral wrote the original plugin.
 
-Andy Wardley E<lt>abw@cre.canon.co.ukE<gt> provided some minor
+Andy Wardley provided some minor
 fixups/enhancements, a test script and documentation.
 
-Mark D. Mills E<lt>mark@hostile.orgE<gt> cloned Date::Manip from the
-cute Date::Calc sub-plugin.
-
-=head1 VERSION
-
-2.77, distributed as part of the
-Template Toolkit version 2.18, released on 09 February 2007.
-
-
+Mark D. Mills cloned C<Date::Manip> from the C<Date::Calc> sub-plugin.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000 Thierry-Michel Barral, Andy Wardley.
+Copyright (C) 2000-2007 Thierry-Michel Barral, Andy Wardley.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template::Plugin|Template::Plugin>, L<POSIX|POSIX>
+L<Template::Plugin>, L<POSIX>
 
